Description Usage Arguments Value Examples
View source: R/lassoGenerationModel.R
Generate data with the Lasso Model
1 2 3 4 5 6 | LassoGenerationModel(
data_signal,
p_freq,
signal_low_significant = 3,
signal_high_significant = 5
)
|
data_signal |
The covariate used to generate the data |
p_freq |
The percentage of covariates that are set to be 0 |
signal_low_significant |
The lower bound on the signal significance, default value is set to be 3 |
signal_high_significant |
The higher bound on the signal significance, default value is set to be 5 |
A list containing the data, covariant, the mask and p_freq
1 2 | out_X = gaussianDistribution(100, 50, "unstructure")
out_Y_Lasso = LassoGenerationModel(out_X$X, 0.5)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.