Description Usage Arguments Value Examples
View source: R/gaussianDistributionGeneration.R
Generate gaussian distribution with provided copula of p features and n samples
1 | gaussianDistributionGeneration(copula, p, n)
|
copula |
Copula used to generate normal distribution |
p |
Number of features |
n |
Number of samples |
A list of data, multivariate mean and multivariate standard deviation
1 2 | out_copula = gaussianCopula(p = 100, n = 500, type = "diag")
out_data = gaussianDistributionGeneration(copula = out_copula, p = 100, n = 500)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.