Description Usage Arguments Examples
Select variable based on knockoff constructed from lasso Regression
1 |
x |
Original data |
x.knockoff |
knockoff copy of the original data |
y |
Response variable |
mask |
The variables that are masked from the purpose |
family |
what kind of |
offset |
Offset for the knock.thershold, either 0 or 1, default is 0 |
fdr_rate |
Controlling the False Discovery Rate of the knockoff |
1 2 3 4 5 | out_copula = gaussianCopula(p = 100, n = 500, type = "diag")
out_data = gaussianDistributionGeneration(copula = out_copula, p = 100, n = 500)
out = copulaKnockoff(out_data$data)
lasso_out = LassoGenerationModel(data_signal = out_data$data, p_freq = 0.3)
lassoFDR(x = out_data$data, x.knockoff = out$x.knockoff.copy, y = lasso_out$y, family = "gaussian")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.